from unittest.mock import patch, call

from rpg_dice import roll


@patch("random.randrange")
def test_1d6(randrange):
    randrange.side_effect = [4]
    assert roll("1d6") == 5
    randrange.assert_called_with(6)


@patch("random.randrange")
def test_2d6(randrange):
    randrange.side_effect = [4, 2]
    assert roll("2d6") == 8
    randrange.assert_has_calls([call(6), call(6)])


@patch("random.randrange")
def test_default_number_of_dice_is_1(randrange):
    randrange.side_effect = [3]
    assert roll("d6") == 4
    randrange.assert_called_with(6)


@patch("random.randrange")
def test_1d20(randrange):
    randrange.side_effect = [17]
    assert roll("1d20") == 18
    randrange.assert_called_with(20)


@patch("random.randrange")
def test_1d2(randrange):
    randrange.side_effect = [1]
    assert roll("1d2") == 2
    randrange.assert_called_with(2)


def test_1d1():
    """ This one isn't really random, 1d1 will always return 1 """
    assert roll("1d1") == 1



import random
import re

DIE_PATTERN = re.compile("(?P<count>\\d*)d(?P<value>\\d+)")


def roll(dice_str):
    search = DIE_PATTERN.search(dice_str)
    count = search.group("count")
    count = int(count) if count else 1
    value = int(search.group("value"))
    return sum(random.randrange(value) + 1 for _ in range(count))



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="rpg-dice",
    version="0.1.0",
    author="Paweł Fertyk",
    author_email="pfertyk@pfertyk.me",
    description="A simple dice roller",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/pfertyk/rpg-dice",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: CC0 1.0 Universal (CC0 1.0) Public Domain Dedication",
        "Operating System :: OS Independent",
    ],
)
